@@ -17,7 +17,7 @@ from .utils import fetch_buckeye_resource,fetch_media_resource,loadFile
 Fillers = set(['uh','um','okay','yes','yeah','oh','heh','yknow','um-huh','uh-uh','uh-huh','uh-hum','mm-hmm'])
 
 def loadSegments():
-    segs = loadFile(fetch_media_resource("SegmentInfo.txt"))
+    segs = loadFile(fetch_buckeye_resource("SegmentInfo.txt"))
     ss = []
     for s in segs:
         ss.append(SegmentType(Label=s['Label'],Syllabic=bool(int(s['Syllabic'])),Obstruent=bool(int(s['Obstruent'])),Nasal=bool(int(s['Nasal'])),Vowel=bool(int(s['Vowel']))))
